<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>Activity</name>
    <message>
        <location filename="../src/activity.cpp" line="166"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ControlCenter</name>
    <message>
        <location filename="../qml/ControlCenter.qml" line="217"/>
        <source>Wi-Fi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="220"/>
        <location filename="../qml/ControlCenter.qml" line="236"/>
        <location filename="../qml/ControlCenter.qml" line="253"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="220"/>
        <location filename="../qml/ControlCenter.qml" line="236"/>
        <location filename="../qml/ControlCenter.qml" line="253"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="235"/>
        <source>Bluetooth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ControlCenter.qml" line="252"/>
        <source>Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="75"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
